pub enum InquireError {
NotTTY,
InvalidConfiguration(String),
IO(Error),
OperationCanceled,
OperationInterrupted,
Custom(Box<dyn Error + Sync + Send>),
}Expand description
Re-export so downstream consumers (and WizardStep impls) can
?-propagate without adding inquire as a direct dependency.
Possible errors returned by inquire prompts.
Variants
NotTTY
The input device is not a TTY, which means that enabling raw mode on the terminal in order to listen to input events is not possible.
InvalidConfiguration(String)
The given prompt configuration is not valid. A detailed error message is contained in the value string.
IO(Error)
Error while executing IO operations.
OperationCanceled
The user canceled the operation by pressing ESC.
OperationInterrupted
The operation was interrupted by the user after they pressed Ctrl+C.
This error will be returned only when using crossterm
or termion as the terminal back-end. If using console,
pressing Ctrl+C will trigger SIGINT.
Custom(Box<dyn Error + Sync + Send>)
Error while executing IO operations.